``eradiate.srf_tools``
=======================

.. automodule:: eradiate.srf_tools

.. py:currentmodule:: eradiate.srf_tools

Trimming algorithms
-------------------

.. autofunction:: trim

.. autofunction:: trim_and_save

Filtering algorithms
--------------------

.. autofunction:: integral_filter

.. autofunction:: spectral_filter

.. autofunction:: threshold_filter

.. autofunction:: filter_srf

Plotting
--------

.. autofunction:: show

Utilities
---------

.. autofunction:: wavelength_range_width

.. autofunction:: wavelength_bandwidth

.. autofunction:: mean_wavelength

.. autofunction:: summarize
